@@ -40,7 +40,6 @@ G_BEGIN_DECLS
 #define BVW_ERROR bacon_video_widget_error_quark ()
 
 typedef struct BaconVideoWidgetPrivate BaconVideoWidgetPrivate;
-typedef struct BaconVideoWidgetCommon BaconVideoWidgetCommon;
 
 /**
  * BaconVideoWidget:
@@ -382,6 +381,38 @@ typedef enum {
 
 void bacon_video_widget_dvd_event                (BaconVideoWidget *bvw,
 						  BvwDVDEvent type);
+
+/**
+ * BvwLangInfo:
+ * @language: the ISO-639 language code for the track, or "und" if unknown.
+ * Can never be %NULL.
+ * @codec: the codec for the track, or %NULL if unknown or unset.
+ *
+ * #BvwLangInfo holds the language code and codec for each subtitle
+ * or audio track for a media, which would allow the front-ends to
+ * present appropriate information to the user.
+ */
+typedef struct {
+	char *language;
+	char *codec;
+} BvwLangInfo;
+
+/**
+ * BvwTrackType:
+ * @BVW_TRACK_TYPE_AUDIO: an audio track
+ * @BVW_TRACK_TYPE_SUBTITLE: a subtitle track
+ * @BVW_TRACK_TYPE_ANGLE: a video track
+ *
+ * A type of media track.
+ */
+typedef enum {
+	BVW_TRACK_TYPE_AUDIO,
+	BVW_TRACK_TYPE_SUBTITLE,
+	BVW_TRACK_TYPE_VIDEO
+} BvwTrackType;
+
+void bacon_video_widget_lang_info_free           (BvwLangInfo *info);
+
 GList *bacon_video_widget_get_languages          (BaconVideoWidget *bvw);
 int bacon_video_widget_get_language              (BaconVideoWidget *bvw);
 void bacon_video_widget_set_language             (BaconVideoWidget *bvw,
