@@ -117,7 +117,7 @@ int main
 			G_CALLBACK (gtk_main_quit), NULL);
 
 	bvw = bacon_video_widget_new (NULL);
-	bacon_video_widget_set_logo (BACON_VIDEO_WIDGET (bvw), "totem");
+	bacon_video_widget_set_logo (BACON_VIDEO_WIDGET (bvw), "org.gnome.Totem");
 
 	g_signal_connect (G_OBJECT (bvw), "eos", G_CALLBACK (on_eos_event), NULL);
 	g_signal_connect (G_OBJECT (bvw), "got-metadata", G_CALLBACK (on_got_metadata), NULL);
