@@ -72,6 +72,34 @@ totem_gst_message_print (GstMessage *msg,
   g_free (dbg);
 }
 
+/* Disable decoders that require a display environment to work,
+ * and that might cause crashes */
+void
+totem_gst_disable_display_decoders (void)
+{
+	GstRegistry *registry;
+	const char *blacklisted_plugins[] = {
+	  "bmcdec",
+	  "vaapi",
+	  "video4linux2"
+	};
+	guint i;
+
+	/* Disable the vaapi plugin as it will not work with the
+	 * fakesink we use:
+	 * See: https://bugzilla.gnome.org/show_bug.cgi?id=700186 and
+	 * https://bugzilla.gnome.org/show_bug.cgi?id=749605 */
+	registry = gst_registry_get ();
+
+	for (i = 0; i < G_N_ELEMENTS (blacklisted_plugins); i++) {
+		GstPlugin *plugin =
+			gst_registry_find_plugin (registry,
+						  blacklisted_plugins[i]);
+		if (plugin)
+			gst_registry_remove_plugin (registry, plugin);
+	}
+}
+
 /*
  * vim: sw=2 ts=8 cindent noai bs=2
  */
