@@ -1,6 +1,6 @@
 import struct
 import os
-from gi.repository import Gio # pylint: disable-msg=E0611
+from gi.repository import Gio
 
 SIZE_ERROR = -1
 SEEK_ERROR = -2
@@ -21,9 +21,9 @@ def hash_file (name):
     if filesize < 65536 * 2:
         return SIZE_ERROR, 0
 
-    file_handle = file (file_to_hash.get_path (), "rb")
+    file_handle = open (file_to_hash.get_path (), "rb")
 
-    for _ in range (65536 / bytesize):
+    for _ in range(int(65536 / bytesize)):
         buf = file_handle.read (bytesize)
         (l_value,) = struct.unpack (longlongformat, buf)
         file_hash += l_value
@@ -34,7 +34,7 @@ def hash_file (name):
     if file_handle.tell() != max (0, filesize - 65536):
         return SEEK_ERROR, 0
 
-    for _ in range (65536/bytesize):
+    for _ in range(int(65536/bytesize)):
         buf = file_handle.read (bytesize)
         (l_value,) = struct.unpack (longlongformat, buf)
         file_hash += l_value
@@ -43,8 +43,4 @@ def hash_file (name):
     file_handle.close ()
     returnedhash = "%016x" % file_hash
 
-    print returnedhash
-    print filesize
-
     return returnedhash, filesize
-
