@@ -1,6 +1,6 @@
 # From code by James Livingston
 
-from gi.repository import GObject, Peas, Totem # pylint: disable-msg=E0611,W0611
+from gi.repository import GObject, Peas, Totem # pylint: disable=no-name-in-module,unused-import
 
 class SamplePython (GObject.Object, Peas.Activatable):
     __gtype_name__ = 'SamplePython'
@@ -12,8 +12,8 @@ class SamplePython (GObject.Object, Peas.Activatable):
 
     def do_activate (self):
         print("Activating sample Python plugin")
-        self.object.action_fullscreen_toggle ()
+        self.object.action_fullscreen_toggle () # pylint: disable=no-member
 
     def do_deactivate (self):
         print("Deactivating sample Python plugin")
-        self.object.action_fullscreen_toggle ()
+        self.object.action_fullscreen_toggle () # pylint: disable=no-member
