@@ -41,6 +41,7 @@ static gboolean totem_playlist_add_one_mrl (TotemPlaylist *playlist,
 					    const char    *display_name,
 					    const char    *content_type,
 					    const char    *subtitle_uri,
+					    gint64         starttime,
 					    gboolean       playing);
 
 typedef gboolean (*ClearComparisonFunc) (TotemPlaylist *playlist, GtkTreeIter *iter, gconstpointer data);
@@ -76,9 +77,6 @@ struct TotemPlaylistPrivate
 	GSettings *settings;
 	GSettings *lockdown_settings;
 
-	/* Current time in the track */
-	char *starttime;
-
 	/* This is a scratch list for when we're removing files */
 	GList *list;
 	guint current_to_be_removed : 1;
@@ -111,6 +109,7 @@ enum {
 	FILE_MONITOR_COL,
 	MOUNT_COL,
 	MIME_TYPE_COL,
+	STARTTIME_COL,
 	NUM_COLS
 };
 
@@ -270,10 +269,10 @@ totem_playlist_save_iter_foreach (GtkTreeModel *model,
 {
 	TotemPlPlaylist *playlist = user_data;
 	TotemPlPlaylistIter pl_iter;
-	gchar *uri, *title, *subtitle_uri, *mime_type;
+	gchar *uri, *title, *subtitle_uri, *mime_type, *starttime_str;
 	TotemPlaylistStatus status;
 	gboolean custom_title;
-	const char *starttime;
+	gint64 starttime;
 
 	gtk_tree_model_get (model, iter,
 			    URI_COL, &uri,
@@ -282,12 +281,20 @@ totem_playlist_save_iter_foreach (GtkTreeModel *model,
 			    SUBTITLE_URI_COL, &subtitle_uri,
 			    PLAYING_COL, &status,
 			    MIME_TYPE_COL, &mime_type,
+			    STARTTIME_COL, &starttime,
 			    -1);
 
-	if (status != TOTEM_PLAYLIST_STATUS_NONE)
-		starttime = g_object_get_data (G_OBJECT (playlist), "starttime");
-	else
-		starttime = NULL;
+	/* Prefer the current position for the starttime, if one is passed */
+	starttime_str = NULL;
+	if (status != TOTEM_PLAYLIST_STATUS_NONE) {
+		gint64 new_starttime;
+
+		new_starttime = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (playlist), "starttime"));
+		if (new_starttime != 0)
+			starttime = new_starttime;
+	}
+	if (starttime != 0)
+		starttime_str = g_strdup_printf ("%" G_GINT64_FORMAT, starttime);
 
 	totem_pl_playlist_append (playlist, &pl_iter);
 	totem_pl_playlist_set (playlist, &pl_iter,
@@ -296,13 +303,14 @@ totem_playlist_save_iter_foreach (GtkTreeModel *model,
 			       TOTEM_PL_PARSER_FIELD_SUBTITLE_URI, subtitle_uri,
 			       TOTEM_PL_PARSER_FIELD_PLAYING, status != TOTEM_PLAYLIST_STATUS_NONE ? "true" : "",
 			       TOTEM_PL_PARSER_FIELD_CONTENT_TYPE, mime_type,
-			       TOTEM_PL_PARSER_FIELD_STARTTIME, starttime,
+			       TOTEM_PL_PARSER_FIELD_STARTTIME, starttime_str,
 			       NULL);
 
 	g_free (uri);
 	g_free (title);
 	g_free (subtitle_uri);
 	g_free (mime_type);
+	g_free (starttime_str);
 
 	return FALSE;
 }
@@ -328,12 +336,8 @@ totem_playlist_save_session_playlist (TotemPlaylist *playlist,
 
 	pl_playlist = totem_pl_playlist_new ();
 
-	if (starttime > 0) {
-		char *starttime_msec;
-
-		starttime_msec = g_strdup_printf ("%" G_GINT64_FORMAT, starttime);
-		g_object_set_data_full (G_OBJECT (pl_playlist), "starttime", starttime_msec, g_free);
-	}
+	if (starttime > 0)
+		g_object_set_data (G_OBJECT (pl_playlist), "starttime", GINT_TO_POINTER (starttime));
 
 	gtk_tree_model_foreach (playlist->priv->model,
 				totem_playlist_save_iter_foreach,
@@ -738,8 +742,8 @@ totem_playlist_entry_parsed (TotemPlParser *parser,
 			     GHashTable *metadata,
 			     TotemPlaylist *playlist)
 {
-	const char *title, *content_type, *subtitle_uri, *starttime;
-	gint64 duration;
+	const char *title, *content_type, *subtitle_uri, *starttime_str;
+	gint64 duration, starttime;
 	gboolean playing;
 
 	/* We ignore 0-length items in playlists, they're usually just banners */
@@ -751,14 +755,10 @@ totem_playlist_entry_parsed (TotemPlParser *parser,
 	content_type = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_CONTENT_TYPE);
 	playing = parse_bool_str (g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_PLAYING));
 	subtitle_uri = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_SUBTITLE_URI);
-	if (playing) {
-		starttime = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_STARTTIME);
-		if (starttime != NULL) {
-			g_free (playlist->priv->starttime);
-			playlist->priv->starttime = g_strdup (starttime);
-		}
-	}
-	totem_playlist_add_one_mrl (playlist, uri, title, content_type, subtitle_uri, playing);
+	starttime_str = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_STARTTIME);
+	starttime = totem_pl_parser_parse_duration (starttime_str, FALSE);
+	starttime = MAX (starttime, 0);
+	totem_playlist_add_one_mrl (playlist, uri, title, content_type, subtitle_uri, starttime, playing);
 }
 
 static gboolean
@@ -801,7 +801,6 @@ totem_playlist_dispose (GObject *object)
 	TotemPlaylist *playlist = TOTEM_PLAYLIST (object);
 
 	g_clear_object (&playlist->priv->parser);
-	g_clear_pointer (&playlist->priv->starttime, g_free);
 	g_clear_object (&playlist->priv->settings);
 	g_clear_object (&playlist->priv->lockdown_settings);
 	g_clear_pointer (&playlist->priv->current, gtk_tree_path_free);
@@ -893,6 +892,7 @@ totem_playlist_add_one_mrl (TotemPlaylist *playlist,
 			    const char *display_name,
 			    const char *content_type,
 			    const char *subtitle_uri,
+			    gint64      starttime,
 			    gboolean    playing)
 {
 	GtkListStore *store;
@@ -912,7 +912,7 @@ totem_playlist_add_one_mrl (TotemPlaylist *playlist,
 
 	uri = totem_create_full_path (mrl);
 
-	g_debug ("totem_playlist_add_one_mrl (): %s %s %s %s %s\n", filename_for_display, uri, display_name, subtitle_uri, playing ? "true" : "false");
+	g_debug ("totem_playlist_add_one_mrl (): %s %s %s %s %"G_GINT64_FORMAT " %s\n", filename_for_display, uri, display_name, subtitle_uri, starttime, playing ? "true" : "false");
 
 	store = GTK_LIST_STORE (playlist->priv->model);
 
@@ -944,6 +944,7 @@ totem_playlist_add_one_mrl (TotemPlaylist *playlist,
 					   FILE_MONITOR_COL, monitor,
 					   MOUNT_COL, mount,
 					   MIME_TYPE_COL, content_type,
+					   STARTTIME_COL, starttime,
 					   -1);
 	g_free (escaped_filename);
 
@@ -986,10 +987,10 @@ static gboolean
 handle_parse_result (TotemPlParserResult res, TotemPlaylist *playlist, const gchar *mrl, const gchar *display_name, GError **error)
 {
 	if (res == TOTEM_PL_PARSER_RESULT_UNHANDLED)
-		return totem_playlist_add_one_mrl (playlist, mrl, display_name, NULL, NULL, FALSE);
+		return totem_playlist_add_one_mrl (playlist, mrl, display_name, NULL, NULL, 0, FALSE);
 	if (res == TOTEM_PL_PARSER_RESULT_ERROR) {
 		g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-			     _("The playlist '%s' could not be parsed. It might be damaged."), display_name ? display_name : mrl);
+			     _("The playlist “%s” could not be parsed. It might be damaged."), display_name ? display_name : mrl);
 
 		return FALSE;
 	}
@@ -1070,28 +1071,14 @@ totem_playlist_add_mrl_finish (TotemPlaylist *playlist, GAsyncResult *result, GE
 	return FALSE;
 }
 
-static gint64
-parse_starttime (TotemPlaylist *playlist)
-{
-	gint64 ret;
-
-	if (playlist->priv->starttime == NULL)
-		return 0;
-	ret = g_ascii_strtoll (playlist->priv->starttime, NULL, 0);
-
-	return ret;
-}
-
 gboolean
 totem_playlist_add_mrl_sync (TotemPlaylist *playlist,
-			     const char    *mrl,
-			     gint64        *starttime)
+			     const char    *mrl)
 {
 	GtkTreeIter iter;
 	gboolean ret;
 
 	g_return_val_if_fail (mrl != NULL, FALSE);
-	g_return_val_if_fail (starttime != NULL, FALSE);
 
 	ret = handle_parse_result (totem_pl_parser_parse (playlist->priv->parser, mrl, FALSE), playlist, mrl, NULL, NULL);
 	if (!ret)
@@ -1108,10 +1095,6 @@ totem_playlist_add_mrl_sync (TotemPlaylist *playlist,
 		if (status == TOTEM_PLAYLIST_STATUS_PAUSED) {
 			gtk_tree_path_free (playlist->priv->current);
 			playlist->priv->current = gtk_tree_model_get_path (playlist->priv->model, &iter);
-
-			*starttime = parse_starttime (playlist);
-			g_clear_pointer (&playlist->priv->starttime, g_free);
-
 			break;
 		}
 		ret = gtk_tree_model_iter_next (playlist->priv->model, &iter);
@@ -1710,6 +1693,36 @@ totem_playlist_get_current_content_type (TotemPlaylist *playlist)
 	return content_type;
 }
 
+gint64
+totem_playlist_steal_current_starttime (TotemPlaylist *playlist)
+{
+	GtkTreeIter iter;
+	gint64 starttime;
+
+	g_return_val_if_fail (TOTEM_IS_PLAYLIST (playlist), 0);
+
+	if (update_current_from_playlist (playlist) == FALSE)
+		return 0;
+
+	gtk_tree_model_get_iter (playlist->priv->model,
+				 &iter,
+				 playlist->priv->current);
+
+	gtk_tree_model_get (playlist->priv->model,
+			    &iter,
+			    STARTTIME_COL, &starttime,
+			    -1);
+
+	/* And reset the starttime so it's only used once,
+	 * hence the "steal" in the API name */
+	gtk_list_store_set (GTK_LIST_STORE (playlist->priv->model),
+			    &iter,
+			    STARTTIME_COL, 0,
+			    -1);
+
+	return starttime;
+}
+
 char *
 totem_playlist_get_title (TotemPlaylist *playlist, guint title_index)
 {
