@@ -122,7 +122,6 @@ struct _TotemObject {
 	gboolean drives_changed;
 
 	/* session */
-	gint64 seek_to_start;
 	gboolean pause_start;
 	guint save_timeout_id;
 
@@ -145,6 +144,7 @@ struct _TotemObject {
 
 	/* other */
 	char *mrl;
+	char *next_subtitle;
 	TotemPlaylist *playlist;
 	GSettings *settings;
 	TotemStates state;
