@@ -31,9 +31,7 @@
 
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
-#include <cairo.h>
 #include <gst/gst.h>
-#include <gdk/gdk.h>
 #include <totem-pl-parser.h>
 
 #include <locale.h>
@@ -47,7 +45,6 @@
 #include <sys/stat.h>
 
 #include "gst/totem-gst-helpers.h"
-#include "gst/totem-time-helpers.h"
 #include "gst/totem-gst-pixbuf-helpers.h"
 #include "totem-resources.h"
 
@@ -385,13 +382,6 @@ thumb_app_setup_play (ThumbApp *app)
 {
 	GstElement *play;
 	GstElement *audio_sink, *video_sink;
-	GstRegistry *registry;
-	const char *blacklisted_plugins[] = {
-	  "bmcdec",
-	  "vaapi",
-	  "video4linux2"
-	};
-	guint i;
 
 	play = gst_element_factory_make ("playbin", "play");
 	audio_sink = gst_element_factory_make ("fakesink", "audio-fake-sink");
@@ -406,19 +396,7 @@ thumb_app_setup_play (ThumbApp *app)
 
 	app->play = play;
 
-	/* Disable the vaapi plugin as it will not work with the
-	 * fakesink we use:
-	 * See: https://bugzilla.gnome.org/show_bug.cgi?id=700186 and
-	 * https://bugzilla.gnome.org/show_bug.cgi?id=749605 */
-	registry = gst_registry_get ();
-
-	for (i = 0; i < G_N_ELEMENTS (blacklisted_plugins); i++) {
-		GstPlugin *plugin =
-			gst_registry_find_plugin (registry,
-						  blacklisted_plugins[i]);
-		if (plugin)
-			gst_registry_remove_plugin (registry, plugin);
-	}
+	totem_gst_disable_display_decoders ();
 }
 
 static void
